=========================================
``psyclone.domain.lfric.algorithm.psyir``
=========================================

.. automodule:: psyclone.domain.lfric.algorithm.psyir

   .. contents::
      :local:

.. currentmodule:: psyclone.domain.lfric.algorithm.psyir
